pub enum FontSource {
Binary(Arc<dyn AsRef<[u8]> + Send + Sync>),
File(PathBuf),
SharedFile(PathBuf, Arc<dyn AsRef<[u8]> + Send + Sync>),
}Expand description
A font source.
Either a raw binary data or a file path.
Stores the whole font and not just a single face.
Variants
Binary(Arc<dyn AsRef<[u8]> + Send + Sync>)
A font’s raw data, typically backed by a Vec
File(PathBuf)
A font’s path.
A font’s raw data originating from a shared file mapping.