pub struct RenderContext {
pub width: u32,
pub height: u32,
pub scale: u32,
pub buffer_width: u32,
pub buffer_height: u32,
pub frame_time: Option<u32>,
}Fields
width: u32Surface width in logical pixels.
height: u32Surface height in logical pixels.
scale: u32Integer Wayland buffer scale used for the current frame.
buffer_width: u32Backing buffer width in physical pixels.
buffer_height: u32Backing buffer height in physical pixels.
frame_time: Option<u32>Trait Implementations
Sourceimpl Clone for RenderContext
impl Clone for RenderContext
Sourcefn clone(&self) -> RenderContext
fn clone(&self) -> RenderContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RenderContext
Sourceimpl Debug for RenderContext
impl Debug for RenderContext
impl Eq for RenderContext
Sourceimpl PartialEq for RenderContext
impl PartialEq for RenderContext
Sourcefn eq(&self, other: &RenderContext) -> bool
fn eq(&self, other: &RenderContext) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RenderContext